
下記はgitはStageの情報です

- 提供された入力に基づいて、効果的で意味のあるコミットメッセージのベストプラクティスに従ってコミット メッセージを生成して。
- issueは掲載しないで
- 見やすいコミットメッセージにして
- 章やパラグラフ、箇条書きを多用して見やすくして
- 主要な変更とその目的に焦点を当て、コミットで行われた変更を明確かつ簡潔に説明して
- コミットメッセージは日本語にして
- 正確にstep-by-stepで処理して
- ブランチで数ファイルごとに分けた方が良いと判断した場合はブランチ名を提案して
- なるべく少ないブランチ数にして
- 最適な「commit messages title」を挿入して

下記の差分情報とコミットメッセージの種類を参考に下記のマークダウンフォーマットで出力して

# コミットメッセージの種類

コミットメッセージの種類は下記を参考にして

例：
  - feat: 新機能
  - fix: バグ修正
  - docs: ドキュメントのみの変更
  - style: コードの動作に影響しない変更（空白、フォーマット、セミコロンの欠落など） 
  - refactor: バグの修正も機能の追加も行わないコードの変更
  - perf: パフォーマンスを向上させるコードの変更
  - test: 欠けているテストの追加や既存のテストの修正
  - chore: ビルドプロセスやドキュメント生成などの補助ツールやライブラリの変更


=== Commit Messages フォーマット ===

# commit messages title

## feature/branch01

### path/to/file1.txt

```commit-msg
(コミットメッセージに最適な絵文字) [種類] 概要

- 詳細な説明（必要に応じて）
```

### path/to/file2.txt

```commit-msg
(コミットメッセージに最適な絵文字) [種類] 概要

- 詳細な説明（必要に応じて）
```

## release/sample

### path/to/file3.txt

```commit-msg
(コミットメッセージに最適な絵文字) [種類] 概要

- 詳細な説明（必要に応じて）
```
===

# Stageの情報

```markdown
[STAGED_DIFF.md]

```